Anim class

Anim represents a single animation state with a name.

totalDuration calculates the total number of frames as Frametime units.

Constructors

Anim(String name, {List<Keyframe>? keyframes, List<Attribute>? attributes})
Creates state Anim called name with provided data.

Properties

attrs List<Attribute>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
keyframes List<Keyframe>
getter/setter pair
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalDuration Frametime
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited