BoomflameAttrsListExtension extension

Extends List over Attribute types only.

on

Methods

allWithName(String name) List<Attribute>

Available on List<Attribute>, provided by the BoomflameAttrsListExtension extension

Returns all Attribute objects equal to name or empty list.
firstWithName(String name) Attribute?

Available on List<Attribute>, provided by the BoomflameAttrsListExtension extension

Returns the first Attribute equal to name or null if not found.