BoomflameListExtension<T> extension

This extension enables circular element iteration over List. For a similar extension for Map, see BoomflameMapExtension.

on

Methods

nextOf(T element, {bool? orFirst}) → T?

Available on List<T>, provided by the BoomflameListExtension extension

Returns the next element adjacent to element or null.
prevOf(T element, {bool? orLast}) → T?

Available on List<T>, provided by the BoomflameListExtension extension

Returns the previous element adjacent to element or null.