BoomflameMapExtension<T, Y extends Anim> extension

This extension enables circular element iteration over Map. For a similar extension for List, see BoomflameListExtension.

on

Methods

nextOf(T key, {bool? orFirst}) → T?

Available on Map<T, Y>, provided by the BoomflameMapExtension extension

Returns the next element adjacent to key or null.
prevOf(T key, {bool? orLast}) → T?

Available on Map<T, Y>, provided by the BoomflameMapExtension extension

Returns the previous element adjacent to key or null.