ElementInfo class

ElementInfo has the lineNumber which it was parsed from and the result element.

Knowing the lineNumber is useful because other parsers using this spec will need to raise additional errors if elements in their document format are missing required Standard.args or have malformed values.

Constructors

ElementInfo(int lineNumber, Element element)

Properties

element → Element
final
hashCode int
The hash code for this object.
no setterinherited
lineNumber int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited