ErrorInfo class

ErrorInfo has the offending line and reason message.

type can be pattern matched with one of the hard-coded ErrorTypes. Constructor ErrorInfo.other sets type to ErrorType.runtime which can be used for your own custom error messages.

Constructors

ErrorInfo(int line, ErrorType type)
ErrorInfo.other(int line, String message)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
line int
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type → ErrorType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited