forward constant
Mode
const forward
Animation plays forward from the first frame to the end (default).
Implementation
static const Mode forward = Mode(0x01);
Animation plays forward from the first frame to the end (default).
static const Mode forward = Mode(0x01);