ParserErrorHandler typedef
ParserErrorHandler receives the errors and line numbers in ErrorInfo.
Implementation
typedef ParserErrorHandler = void Function(List<ErrorInfo> errors);
ParserErrorHandler receives the errors and line numbers in ErrorInfo.
typedef ParserErrorHandler = void Function(List<ErrorInfo> errors);