Document class
Document represents a fully-parsed .anim file.
It has a hash map of states which can be used to lookup Anim objects by their Anim.name.
The global values !frame_rate and !image_path are stored in
imagePath and frameRate respectively.
Constructors
- Document()
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited