Frametime extension type
An extension over int storing the value in count.
Frametime units are for frame-perfect or even pixel-perfect applications. They cannot be fractional. For frames over a delay, see Tickrate.
This extension overrides the basic addition, subtraction, and comparison operators. Shorthand inc and dec functions are provided for one tick.
Conversions from Duration are lossy because only full frames are counted.
- on
Constructors
Methods
Operators
-
operator +(
Frametime val) → Frametime -
operator -(
Frametime val) → Frametime -
operator <(
Frametime other) → bool -
operator <=(
Frametime other) → bool -
operator >(
Frametime other) → bool -
operator >=(
Frametime other) → bool
Static Properties
- framesPerSecond ↔ int
-
Mutable framesPerSecond can be changed. Represents
hzor frame rate.getter/setter pair