IndexedKeyframe class
IndexedKeyframe associates a Keyframe with its element index.
Properties
- data ↔ Keyframe
-
The data of the Keyframe we are interested in.
getter/setter pair
- endedThisFrame → bool
-
If true, indicates data has completed after a call to update.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index ↔ int
-
The element index of the data keyframe in an Anim.
getter/setter pair
- isLast → bool
-
If true, indicates data is the last frame in the sequence.
final
- newThisFrame → bool
-
If true, indicates data was stored after a call to update.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited