Mode extension type
Play Mode types can be combined. Default is Mode.forward.
- on
Operators
-
operator &(
Mode mode) → Mode -
Bitwise subtract removes
mode. -
operator |(
Mode mode) → Mode -
Bitwise add combines
mode.
Constants
- bounce → const Mode
- Animation plays forward, then backward, if Mode.loop is present.
- forward → const Mode
- Animation plays forward from the first frame to the end (default).
- loop → const Mode
- Animation will start over and repeat seemlessly.
- reverse → const Mode
- Animation plays from the end to the first frame.
- stop → const Mode
- No animation plays.